@@ -5,14 +5,15 @@ import requests
 
 
 class Uploader(object):
-    def __init__(self, access_token, host):
-        self.access_token = access_token
+    def __init__(self, source_token, host):
+        self.source_token = source_token
         self.host = host
+        self.session = requests.Session()
         self.headers = {
-            'Authorization': 'Bearer %s' % access_token,
+            'Authorization': 'Bearer %s' % source_token,
             'Content-Type': 'application/msgpack',
         }
 
     def __call__(self, frame):
         data = msgpack.packb(frame, use_bin_type=True)
-        return requests.post(self.host, data=data, headers=self.headers)
+        return self.session.post(self.host, data=data, headers=self.headers)
